Rdocumentation
powered by
Learn R Programming
STMedianPolish (version 0.1)
MedianPolishM: Median polish multidimensional.
Description
Fits an additive model for multidimensional array, using Tukey's median polish procedure.
Usage
MedianPolishM(data, ...)
Arguments
data
object of class array, table, or matrix, see details.
...
default arguments, see
MedianPolishM.default
Value
An object of class medpolish with the following named components in a list:
residuals
the residuals.
overall
the fitted constant term.
effects
the fitted every dimensions effects fo array multidimensional.
iter
number of iterations used in the range maxiter.
Details
The function MedianPolishM is generic. See the documentation for
MedianPolishM.default
for further details.
References
Hoaglin, D. C., Mosteller, F., & Tukey, J. W. (Eds.). (2011).
Exploring data tables, trends, and shapes
(Vol. 101). John Wiley & Sons.
[link]