Learn R Programming

STMedianPolish (version 0.1)

MedianPolishM.default: Median polish multidimensional.

Description

Fits an additive model for multidimensional array, using Tukey's median polish procedure.

Usage

"MedianPolishM"(data, eps = 0.01, maxiter = 10L, na.rm = TRUE, ...)

Arguments

data
object of class array, table, or matrix, see details.
eps
real number greater than 0, default 0.01. A tolerance for convergence: see Details
maxiter
the maximum number of iterations. Default 10.
na.rm
logical. If the data contains NA's. Default TRUE.
...
ignored.

Value

An object of class medpolish with the following named components in a list:
residuals
the residuals.
overall
the fitted constant term.
effects
the fitted every dimensions effects of array multidimensional.
iter
number of iterations used in the range maxiter.

Details

the model fitted is additive $constant + dim_{1} + dim_{2} + \cdots + dim_{n}$. The algorithm works by alternately removing medians of $dim_{1}, \cdots, dim_{n}$, and continues until the proportional reduction in the sum of absolute residuals is less than eps or until there have been maxiter iterations. If na.rm is FALSE the presence of any NA value in x will cause an error, otherwise NA values are ignored. MedianPolishM returns an object of class MedianPolishM (see below). There are a plotting method for this class, plot.MedianPolishM.

References

Hoaglin, D. C., Mosteller, F., & Tukey, J. W. (Eds.). (2011). Exploring data tables, trends, and shapes (Vol. 101). John Wiley & Sons.[link]

Examples

Run this code
A<-MedianPolishM(UCBAdmissions, eps=0.1, maxiter=2, na.rm=TRUE)
plot(A)

Run the code above in your browser using DataLab