Learn R Programming

STMedianPolish (version 0.1)

Mpplot: Traces of the space.

Description

Plot of three - dimensional perspective spatial, divides every window into quadrats defined for delta (see ConstructMPst) and counts the numbers of points in each quadrat.

Usage

Mpplot(MpData)

Arguments

MpData
object of class ConstructMPst.

Value

Graphic in three perspectives the space data "x", "y", "z" with divisions that containing the number of points in each quadrat.

Examples

Run this code
data(Metadb)
x<-matrix(0,1,37)
for(i in 1:37){
 x[,i] <- 2007 + (seq(0, 36)/12)[i]
}
x<-as.Date (as.yearmon(x), frac = 1)
time = as.POSIXct(x, tz = "GMT")

MPST<-ConstructMPst(Metadb[,-c(1:4)],time,pts=Metadb[,2:4],Delta=c(7,6,5))
Mpplot(MPST)

Run the code above in your browser using DataLab