plot.MedianPolishM: Plot Median polish multidimensional.
Description
Plot the effects of an additive model for multidimensional array, using Tukey's median polish procedure.
Usage
"plot"(x, ...)
Arguments
x
object of class MedianPolishM.
...
ignored.
Details
The object of class MedianPolish has a list of components of effects that allow to graphic after each iterations, the behavior of this components. If the medianpolish is apply to data of class ConstructutMPst, this method has a specific graphic for data with space - time variability.
References
Hoaglin, D. C., Mosteller, F., & Tukey, J. W. (Eds.). (2011). Exploring data tables, trends, and shapes (Vol. 101). John Wiley & Sons.[link]